summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/kapp/app.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/kapp/app.cpp')
-rw-r--r--languages/cpp/app_templates/kapp/app.cpp52
1 files changed, 26 insertions, 26 deletions
diff --git a/languages/cpp/app_templates/kapp/app.cpp b/languages/cpp/app_templates/kapp/app.cpp
index 5460bba9..6388f452 100644
--- a/languages/cpp/app_templates/kapp/app.cpp
+++ b/languages/cpp/app_templates/kapp/app.cpp
@@ -3,10 +3,10 @@
#include "%{APPNAMELC}.h"
#include "pref.h"
-#include <qdragobject.h>
+#include <tqdragobject.h>
#include <kprinter.h>
-#include <qpainter.h>
-#include <qpaintdevicemetrics.h>
+#include <tqpainter.h>
+#include <tqpaintdevicemetrics.h>
#include <kglobal.h>
#include <klocale.h>
@@ -49,10 +49,10 @@
setupGUI();
// allow the view to change the statusbar and caption
- connect(m_view, SIGNAL(signalChangeStatusbar(const QString&)),
- this, SLOT(changeStatusbar(const QString&)));
- connect(m_view, SIGNAL(signalChangeCaption(const QString&)),
- this, SLOT(changeCaption(const QString&)));
+ connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
+ this, TQT_SLOT(changeStatusbar(const TQString&)));
+ connect(m_view, TQT_SIGNAL(signalChangeCaption(const TQString&)),
+ this, TQT_SLOT(changeCaption(const TQString&)));
}
@@ -62,7 +62,7 @@
void %{APPNAME}::load(const KURL& url)
{
- QString target;
+ TQString target;
// the below code is what you should normally do. in this
// example case, we want the url to our own. you probably
// want to use this code instead for your app
@@ -88,19 +88,19 @@ void %{APPNAME}::load(const KURL& url)
void %{APPNAME}::setupActions()
{
- KStdAction::openNew(this, SLOT(fileNew()), actionCollection());
- KStdAction::open(this, SLOT(fileOpen()), actionCollection());
- KStdAction::save(this, SLOT(fileSave()), actionCollection());
- KStdAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
- KStdAction::print(this, SLOT(filePrint()), actionCollection());
- KStdAction::quit(kapp, SLOT(quit()), actionCollection());
+ KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
+ KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
+ KStdAction::save(this, TQT_SLOT(fileSave()), actionCollection());
+ KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
+ KStdAction::print(this, TQT_SLOT(filePrint()), actionCollection());
+ KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
- KStdAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
+ KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
// this doesn't do anything useful. it's just here to illustrate
// how to insert a custom menu and menu item
KAction *custom = new KAction(i18n("Cus&tom Menuitem"), 0,
- this, SLOT(optionsPreferences()),
+ this, TQT_SLOT(optionsPreferences()),
actionCollection(), "custom_action");
}
@@ -126,19 +126,19 @@ void %{APPNAME}::readProperties(KConfig *config)
// the app is being restored. read in here whatever you wrote
// in 'saveProperties'
- QString url = config->readPathEntry("lastURL");
+ TQString url = config->readPathEntry("lastURL");
if (!url.isEmpty())
m_view->openURL(KURL(url));
}
-void %{APPNAME}::dragEnterEvent(QDragEnterEvent *event)
+void %{APPNAME}::dragEnterEvent(TQDragEnterEvent *event)
{
// accept uri drops only
event->accept(KURLDrag::canDecode(event));
}
-void %{APPNAME}::dropEvent(QDropEvent *event)
+void %{APPNAME}::dropEvent(TQDropEvent *event)
{
// this is a very simplistic implementation of a drop event. we
// will only accept a dropped URL. the Qt dnd code can do *much*
@@ -173,10 +173,10 @@ void %{APPNAME}::fileOpen()
// button is clicked
/*
// this brings up the generic open dialog
- KURL url = KURLRequesterDlg::getURL(QString::null, this, i18n("Open Location") );
+ KURL url = KURLRequesterDlg::getURL(TQString::null, this, i18n("Open Location") );
*/
// standard filedialog
- KURL url = KFileDialog::getOpenURL(QString::null, QString::null, this, i18n("Open Location"));
+ KURL url = KFileDialog::getOpenURL(TQString::null, TQString::null, this, i18n("Open Location"));
if (!url.isEmpty())
m_view->openURL(url);
}
@@ -209,13 +209,13 @@ void %{APPNAME}::filePrint()
if (m_printer->setup(this))
{
// setup the printer. with Qt, you always "print" to a
// QPainter.. whether the output medium is a pixmap, a screen,
// or paper
- QPainter p;
+ TQPainter p;
p.begin(m_printer);
// we let our view do the actual printing
- QPaintDeviceMetrics metrics(m_printer);
+ TQPaintDeviceMetrics metrics(m_printer);
m_view->print(&p, metrics.height(), metrics.width());
// and send the result to the printer
@@ -233,13 +233,13 @@ void %{APPNAME}::optionsPreferences()
}
}
-void %{APPNAME}::changeStatusbar(const QString& text)
+void %{APPNAME}::changeStatusbar(const TQString& text)
{
// display the text on the statusbar
statusBar()->message(text);
}
-void %{APPNAME}::changeCaption(const QString& text)
+void %{APPNAME}::changeCaption(const TQString& text)
{
// display the text on the caption
setCaption(text);
@@ -209,13 +209,13 @@ void %{APPNAME}::filePrint()
{
// setup the printer. with Qt, you always "print" to a
- // QPainter.. whether the output medium is a pixmap, a screen,
+ // TQPainter.. whether the output medium is a pixmap, a screen,
// or paper